LazyJioAsyncProvider<T extends JioNotifier> class

🦅 Async Fenix Lazy Provider with reference counting

Constructors

LazyJioAsyncProvider(Future<T> createAsync(), {bool autoDispose = true})

Properties

autoDispose → bool
final
createAsync → Future<T> Function()
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(Widget child) → Widget
getInstance() → Future<T>
Get the instance, creating it if necessary
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited