JioContext extension
🔧 BuildContext extension methods for easier usage
- on
Methods
-
fenixWatch<
T extends JioNotifier> () → T? -
Available on BuildContext, provided by the JioContext extension
Synchronous access to the notifier (throws if not found) -
maybeWatch<
T extends JioNotifier> () → T? -
Available on BuildContext, provided by the JioContext extension
Synchronous access to the notifier if already created, else null -
read<
T extends JioNotifier> () → T -
Available on BuildContext, provided by the JioContext extension
🪄 Read without rebuild — useful for methods or callbacks Does not rebuild (for actions, callbacks, etc.) -
watch<
T extends JioNotifier> () → T -
Available on BuildContext, provided by the JioContext extension
🪄 Watch for changes — rebuilds when notifyListeners() is called