LazyJioProvider<T extends JioNotifier> class
💤 Fenix-style Lazy provider - created only when accessed for the first time
Constructors
- LazyJioProvider(T create(), {bool autoDispose = true})
Properties
- autoDispose → bool
-
final
- create → T Function()
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
Widget child) → Widget -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited