LazyJioUniversalProvider<T extends JioNotifier> class
🦅 Universal Fenix Lazy Provider (sync or async)
Constructors
-
LazyJioUniversalProvider(FutureOr<
T> creator(), {bool autoDispose = true})
Properties
- autoDispose → bool
-
final
-
creator
→ FutureOr<
T> Function() -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maybeInstance → T?
-
🪄 Synchronous access if already created, else null
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
Widget child) → Widget -
getInstance(
) → Future< T> - Get instance, creating lazily Lazy creation (sync or async)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of<
T extends JioNotifier> (BuildContext context) → T? - 🪄 Watch / access from context